@@ -77,6 +77,36 @@ static std::string test_String()
         return "failed (3)";
     }
 
+    // ord tests
+    Py::Char c3 = r2[2];
+    long v3 = c3.ord();
+    if( v3 != '3' )
+    {
+        std::cout << "string ord value < 2^7 " << v3 << " vs. " << '3' << std::endl;
+        return "failed (4)";
+    }
+
+    std::cout << "sizeof( Py_UNICODE ) " << sizeof( Py_UNICODE ) << std::endl;
+
+    // python2 only handles unicode < 2^16.
+    Py_UNICODE u4( 0x20ac );
+    Py::Char c4( u4 );
+    long v4 = c4.ord();
+    if( v4 != 0x20ac )
+    {
+        std::cout << "string ord value > 2^16 " << v4 << " vs. " << 0x20ac << std::endl;
+        return "failed (5)";
+    }
+
+    Py::Char c5( '\xd5' );
+    long v5 = c5.ord();
+    if( v5 != 0xd5 )
+    {
+        std::cout << "string ord value < 2^8 " << v5 << " vs. " << 0xd5 << std::endl;
+        return "failed (6)";
+    }
+
+    // convert tests
     Py::Char c7 = r2.front();
     Py::Char c8 = r2.back();
 
@@ -188,6 +218,21 @@ test_numbers()
         return "failed 9";
     }
 
+#ifdef HAVE_LONG_LONG
+    long long cxx_long_long11 = 1152921504616856976ll;
+    long long cxx_long_long12 = 6152921504616856976ll;
+    Py::Long py_long11( cxx_long_long11 );
+    Py::Long py_long12( 100 );
+
+    if( !(cxx_long_long11 == py_long11.as_long_long() )) return "failed (100)";
+    if( !(1152921504616856976ll == py_long11.as_long_long() )) return "failed (101)";
+    if( !(100ll == py_long12.as_long_long() )) return "failed (101)";
+
+    py_long12 = cxx_long_long12;
+
+    if( !(cxx_long_long12 == py_long12.as_long_long() )) return "failed (101)";
+#endif
+
     return "ok";
 }
 
@@ -231,7 +276,7 @@ test_List_iterators (const Py::List& x, Py::List& y)
         std::cout << "About to raise exception int(\"Howdy\")" << std::endl;
         o2 = o1;
     } 
-    catch (Py::Exception &e)
+    catch (Py::BaseException &e)
     {
         std::cout << "Catch o.k." << std::endl;
         caught_it = 1;
@@ -364,7 +409,7 @@ test_Tuple()
         t[0] = Py::Int(1); // should fail, tuple has multiple references
         return "failed 2";
     }
-    catch (Py::Exception& e)
+    catch (Py::BaseException& e)
     {
         e.clear();
     }
@@ -569,7 +614,7 @@ private:
             a.verify_length(0);
             std::cout << "I see that you refuse to give me any work to do." << std::endl;
         }
-        catch (Py::Exception& e)
+        catch (Py::BaseException& e)
         {
             e.clear();
             std::cout << "I will now add up your elements, oh great one." << std::endl;
@@ -600,8 +645,8 @@ private:
         catch (Py::TypeError& e)
         {
             std::cout << "Correctly caught " << Py::type(e) << std::endl;
-            std::cout << "  Py::Exception value: " << Py::value(e) << std::endl;
-            std::cout << "  Py::Exception traceback: " << Py::trace(e) << std::endl;
+            std::cout << "  Py::BaseException value: " << Py::value(e) << std::endl;
+            std::cout << "  Py::BaseException traceback: " << Py::trace(e) << std::endl;
             e.clear();
         }
 
@@ -615,8 +660,8 @@ private:
         catch (Py::TypeError& e)
         {
             std::cout << "Correctly caught " << Py::type(e) << std::endl;
-            std::cout << "  Py::Exception value: " << Py::value(e) << std::endl;
-            std::cout << "  Py::Exception traceback: " << Py::trace(e) << std::endl;
+            std::cout << "  Py::BaseException value: " << Py::value(e) << std::endl;
+            std::cout << "  Py::BaseException traceback: " << Py::trace(e) << std::endl;
             e.clear();
         }
 
@@ -631,8 +676,8 @@ private:
         catch (Py::TypeError& e)
         {
             std::cout << "Correctly caught " << Py::type(e) << std::endl;
-            std::cout << "  Py::Exception value: " << Py::value(e) << std::endl;
-            std::cout << "  Py::Exception traceback: " << Py::trace(e) << std::endl;
+            std::cout << "  Py::BaseException value: " << Py::value(e) << std::endl;
+            std::cout << "  Py::BaseException traceback: " << Py::trace(e) << std::endl;
             e.clear();
         }
 
