@@ -1,4 +1,4 @@
-
+#
 #   Copyright (c) 2010-2011 Barry A. Scott
 #
 import os
@@ -22,6 +22,7 @@ class Setup:
 
         self.opt_debug = False
         self.opt_pycxx_debug = False
+        self.opt_limited_api = None
 
         self.platform = args[0]
         del args[0]
@@ -34,10 +35,25 @@ class Setup:
                 self.opt_debug = True
                 del args[0]
 
-            if args[0] == '--pycxx-debug':
+            elif args[0] == '--pycxx-debug':
                 self.opt_pycxx_debug = True
                 del args[0]
 
+            elif args[0] == '--limited-api':
+                self.opt_limited_api = '0x03040000'
+                del args[0]
+
+            elif args[0].startswith( '--limited-api=' ):
+                api = args[0][len('--limited-api='):]
+                if api.startswith( '0x' ):
+                    self.opt_limited_api = api
+                else:
+                    major, minor = [int(s) for s in api.split('.')]
+                    minor *= 0x10000
+                    major *= 0x1000000
+                    self.opt_limited_api = '0x%x' % (major+minor)
+                del args[0]
+
             else:
                 raise ValueError( 'Unknown arg %r' % (args[0],) )
 
@@ -184,12 +200,16 @@ class Compiler:
             raise ValueError( 'Cannot translate string (%s)' % (e,) )
 
 
+# MSVC 9.0 and later versions
 class Win32CompilerMSVC90(Compiler):
     def __init__( self, setup ):
         Compiler.__init__( self, setup )
 
         self._addVar( 'PYTHONDIR',      sys.exec_prefix )
-        self._addVar( 'PYTHON_LIBNAME', 'python%d%d' % (sys.version_info[0], sys.version_info[1]) )
+        if setup.opt_limited_api is None:
+            self._addVar( 'PYTHON_LIBNAME', 'python%d%d' % (sys.version_info[0], sys.version_info[1]) )
+        else:
+            self._addVar( 'PYTHON_LIBNAME', 'python3' )
         self._addVar( 'PYTHON_INCLUDE', r'%(PYTHONDIR)s\include' )
         self._addVar( 'PYTHON_LIB',     r'%(PYTHONDIR)s\libs' )
         self._addVar( 'PYTHON',         sys.executable )
@@ -205,7 +225,7 @@ class Win32CompilerMSVC90(Compiler):
 
     def generateMakefileHeader( self ):
         self.makePrint( '#' )
-        self.makePrint( '#	Bemacs Makefile generated by setup.py' )
+        self.makePrint( '#	PyCXX Makefile generated by setup_makefile.py' )
         self.makePrint( '#' )
         self.makePrint( 'CCC=cl /nologo /W4' )
         self.makePrint( 'CC=cl /nologo /W4' )
@@ -279,6 +299,7 @@ class Win32CompilerMSVC90(Compiler):
         self._addVar( 'DEMO_DIR',       'Demo\Python%d' % (sys.version_info[0],) )
 
         self._addVar( 'PYCXX_DEBUG',    '-DPYCXX_DEBUG=1' if self.setup.opt_pycxx_debug else '' )
+        self._addVar( 'PYCXX_API',      ('-DPy_LIMITED_API=%s' % (self.setup.opt_limited_api,)) if self.setup.opt_limited_api else '' )
 
         self._addVar( 'CCCFLAGS',
                                         r'/Zi /MT /EHsc '
@@ -286,7 +307,8 @@ class Win32CompilerMSVC90(Compiler):
                                         r'-D_CRT_NONSTDC_NO_DEPRECATE '
                                         r'-U_DEBUG '
                                         r'-D%(DEBUG)s '
-                                        r'%(PYCXX_DEBUG)s' )
+                                        r'%(PYCXX_DEBUG)s'
+                                        r'%(PYCXX_API)s' )
 
     def ruleTest( self, python_test ):
         rules = []
@@ -327,7 +349,7 @@ class CompilerGCC(Compiler):
 
     def generateMakefileHeader( self ):
         self.makePrint( '#' )
-        self.makePrint( '#	Bemacs Makefile generated by setup.py' )
+        self.makePrint( '#	PyCXX Makefile generated by setup_makefile.py' )
         self.makePrint( '#' )
         self.makePrint( '' )
 
@@ -415,13 +437,15 @@ class MacOsxCompilerGCC(CompilerGCC):
         self._addVar( 'DEMO_DIR',       'Demo/Python%d' % (sys.version_info[0],) )
 
         self._addVar( 'PYCXX_DEBUG',    '-DPYCXX_DEBUG=1' if self.setup.opt_pycxx_debug else '' )
+        self._addVar( 'PYCXX_API',      ('-DPy_LIMITED_API=%s' % (self.setup.opt_limited_api,)) if self.setup.opt_limited_api else '' )
 
         self._addVar( 'CCCFLAGS',
                                         '-g '
                                         '-Wall -fPIC -fexceptions -frtti '
                                         '-I. -ISrc -I%(PYTHON_INCLUDE)s '
                                         '-D%(DEBUG)s '
-                                        '%(PYCXX_DEBUG)s' )
+                                        '%(PYCXX_DEBUG)s'
+                                        '%(PYCXX_API)s' )
 
         self._addVar( 'LDSHARED',       '%(CCC)s -bundle -g '
                                         '-framework System '
@@ -442,12 +466,14 @@ class LinuxCompilerGCC(CompilerGCC):
         self._addVar( 'PYTHON_VERSION', '%d.%d' % (sys.version_info[0], sys.version_info[1]) )
         self._addVar( 'PYTHON_INCLUDE', distutils.sysconfig.get_python_inc() )
         self._addVar( 'PYCXX_DEBUG',    '-DPYCXX_DEBUG=1' if self.setup.opt_pycxx_debug else '' )
+        self._addVar( 'PYCXX_API',      ('-DPy_LIMITED_API=%s' % (self.setup.opt_limited_api,)) if self.setup.opt_limited_api else '' )
         self._addVar( 'CCCFLAGS',
                                         '-g '
                                         '-Wall -fPIC -fexceptions -frtti '
                                         '-I. -ISrc -I%(PYTHON_INCLUDE)s '
                                         '-D%(DEBUG)s '
-                                        '%(PYCXX_DEBUG)s' )
+                                        '%(PYCXX_DEBUG)s'
+                                        '%(PYCXX_API)s' )
 
         self._addVar( 'LDEXE',          '%(CCC)s -g' )
         self._addVar( 'LDSHARED',       '%(CCC)s -shared -g ' )
