@@ -109,7 +109,7 @@ extern "C" svn_error_t *handlerLogMsg2
     apr_pool_t *pool
     )
 {
-    SvnContext *context = reinterpret_cast<SvnContext *>( baton );
+    SvnContext *context = SvnContext::castBaton( baton );
 
     std::string msg;
 
@@ -131,7 +131,7 @@ extern "C" svn_error_t *handlerLogMsg
     apr_pool_t *pool
     )
 {
-    SvnContext *context = reinterpret_cast<SvnContext *>( baton );
+    SvnContext *context = SvnContext::castBaton( baton );
 
     std::string msg;
 
@@ -153,7 +153,7 @@ extern "C" void handlerNotify2
     apr_pool_t *pool
     )
 {
-    SvnContext *context = reinterpret_cast<SvnContext *>( baton );
+    SvnContext *context = SvnContext::castBaton( baton );
 
     context->contextNotify2( notify, pool );
 }
@@ -172,7 +172,7 @@ extern "C" void handlerNotify
 {
     pysvn_bpt();
 
-    SvnContext *context = reinterpret_cast<SvnContext *>( baton );
+    SvnContext *context = SvnContext::castBaton( baton );
 
     context->contextNotify( path, action, kind, mime_type, content_state, prop_state, revision );
 }
@@ -187,7 +187,7 @@ extern "C" void handlerProgress
     apr_pool_t *pool
     )
 {
-    SvnContext *context = reinterpret_cast<SvnContext *>( baton );
+    SvnContext *context = SvnContext::castBaton( baton );
 
     context->contextProgress( progress, total );
 }
@@ -202,7 +202,7 @@ extern "C" svn_error_t *handlerConflictResolver
     apr_pool_t *pool
     )
 {
-    SvnContext *context = reinterpret_cast<SvnContext *>( baton );
+    SvnContext *context = SvnContext::castBaton( baton );
 
     if( context->contextConflictResolver( result, description, pool ) )
         return SVN_NO_ERROR;
@@ -216,7 +216,7 @@ extern "C" svn_error_t *handlerCancel
     void * baton
     )
 {
-    SvnContext *context = reinterpret_cast<SvnContext *>( baton );
+    SvnContext *context = SvnContext::castBaton( baton );
 
     if( context->contextCancel() )
         return svn_error_create( SVN_ERR_CANCELLED, NULL, "cancelled by user" );
@@ -234,7 +234,7 @@ extern "C" svn_error_t *handlerSimplePrompt
     apr_pool_t *pool
     )
 {
-    SvnContext *context = reinterpret_cast<SvnContext *>( baton );
+    SvnContext *context = SvnContext::castBaton( baton );
 
     bool may_save = a_may_save != 0;
 
@@ -271,7 +271,7 @@ extern "C" svn_error_t *handlerSslServerTrustPrompt
     apr_pool_t *pool
     )
 {
-    SvnContext *context = reinterpret_cast<SvnContext *>( baton );
+    SvnContext *context = SvnContext::castBaton( baton );
 
     apr_uint32_t accepted_failures = failures;
     bool accept_permanently = true;
@@ -292,9 +292,10 @@ extern "C" svn_error_t *handlerSslServerTrustPrompt
     if( accept_permanently )
     {
         new_cred->may_save = 1;
-        new_cred->accepted_failures = accepted_failures;
     }
 
+    new_cred->accepted_failures = accepted_failures;
+
     *cred = new_cred;
 
     return SVN_NO_ERROR;
@@ -309,7 +310,7 @@ extern "C" svn_error_t *handlerSslClientCertPrompt
     apr_pool_t *pool
     )
 {
-    SvnContext *context = reinterpret_cast<SvnContext *>( baton );
+    SvnContext *context = SvnContext::castBaton( baton );
 
     if( a_realm == NULL )
         a_realm = "";
@@ -339,7 +340,7 @@ extern "C" svn_error_t *handlerSslClientCertPwPrompt
     apr_pool_t *pool
     )
 {
-    SvnContext *context = reinterpret_cast<SvnContext *>( baton );
+    SvnContext *context = SvnContext::castBaton( baton );
 
     if( a_realm == NULL )
         a_realm = "";
@@ -370,12 +371,15 @@ SvnContext::SvnContext( const std::string &config_dir_str )
 
     apr_pool_create( &m_pool, NULL );
 
+#if defined( PYSVN_HAS_CLIENT_CREATE_CONTEXT2 )
+    svn_client_create_context2( &m_context, NULL, m_pool );
+#else
     svn_client_create_context( &m_context, m_pool );
+#endif
 
     if( !config_dir_str.empty() )
     {
-        m_config_dir = new char[config_dir_str.size() + 1];
-        strcpy( m_config_dir, config_dir_str.c_str() );
+        m_config_dir = svn_dirent_canonicalize( config_dir_str.c_str(), m_pool );
     }
 
     svn_config_ensure( m_config_dir, m_pool );
@@ -559,8 +563,6 @@ void SvnContext::installConflictResolver( bool install )
 
 SvnContext::~SvnContext()
 {
-    delete m_config_dir;
-
     if( m_pool )
     {
         apr_pool_destroy( m_pool );
@@ -604,7 +606,18 @@ svn_error_t *SvnTransaction::init( const std::string &repos_path,
     const std::string &transaction_name, bool is_revision )
 {
     svn_error_t *error;
+
+    SvnPool scratch_pool( *this );
+
+#if defined( PYSVN_HAS_REPOS_OPEN3 )
+    error = svn_repos_open3( &m_repos, repos_path.c_str(), NULL, m_pool, scratch_pool );
+
+#elif defined( PYSNV_HAS_REPOS_OPEN2 )
+    error = svn_repos_open2( &m_repos, repos_path.c_str(), NULL, m_pool );
+
+#else
     error = svn_repos_open( &m_repos, repos_path.c_str(), m_pool );
+#endif
     if( error != NULL )
         return error;
 
