@@ -221,7 +221,7 @@
 #define PYSVN_HAS_CLIENT_GET_MERGING_SUMMARY QQQ
 #define PYSVN_HAS_CLIENT_GET_REPOS_ROOT 1
 #define PYSVN_HAS_CLIENT_IMPORT5 QQQ
-#define PYSVN_HAS_CLIENT_LIST3 QQQ
+#define PYSVN_HAS_CLIENT_LIST3 1
 #define PYSVN_HAS_CLIENT_MERGE5 QQQ
 #define PYSVN_HAS_CLIENT_MERGEINFO_LOG2 QQQ
 #define PYSVN_HAS_CLIENT_MERGE_PEG5 QQQ
@@ -244,6 +244,11 @@
 #define PYSVN_HAS_REPOS_OPEN3 1
 #endif
 
+#if (SVN_VER_MAJOR == 1 && SVN_VER_MINOR >= 10) || SVN_VER_MAJOR > 1
+#define PYSVN_HAS_SVN_1_10
+#define PYSVN_HAS_CLIENT_LIST4 1
+#endif
+
 #if defined( PYSVN_HAS_CLIENT_STATUS3 )
 typedef svn_wc_status2_t pysvn_wc_status_t;
 
