@@ -1,6 +1,6 @@
 #
 # ====================================================================
-# Copyright (c) 2005-2016 Barry A Scott.  All rights reserved.
+# Copyright (c) 2005-2018 Barry A Scott.  All rights reserved.
 #
 # This software is licensed as described in the file LICENSE.txt,
 # which you should have received as part of this distribution.
@@ -25,7 +25,7 @@ class SetupError(Exception):
     pass
 
 # version of PyCXX that we require
-min_pycxx_version = (6, 2, 8)
+min_pycxx_version = (7, 0, 2)
 
 _debug = False
 
@@ -715,7 +715,7 @@ class Win32CompilerMSVC90(Compiler):
         return '.obj'
 
     def getTouchCommand( self ):
-        return r'c:\UnxUtils\touch'
+        return r'C:\UnxUtils\usr\local\wbin\touch.exe'
 
     def generateMakefileHeader( self ):
         self.makePrint( '#' )
@@ -832,6 +832,7 @@ class Win32CompilerMSVC90(Compiler):
                     r'%(SVN_LIB)s\libsvn_ra-1.lib',
                     r'%(SVN_LIB)s\libsvn_ra_local-1.lib',
                     r'%(SVN_LIB)s\libsvn_ra_svn-1.lib',
+                    r'%(SVN_LIB)s\libsvn_ra_serf-1.lib',
                     r'%(SVN_LIB)s\libsvn_repos-1.lib',
                     r'%(SVN_LIB)s\libsvn_subr-1.lib',
                     r'%(SVN_LIB)s\libsvn_wc-1.lib',
@@ -1138,7 +1139,7 @@ class MacOsxCompilerGCC(CompilerGCC):
                     '-D%(DEBUG)s',
                     ]
 
-        if self.pycxx_version >= (7, 0, 0):
+        if False and self.pycxx_version >= (7, 0, 0):
             # PYSVN uses PYCXX in backward compat mode
             py_cflags_list.append( r'-DPYCXX_6_2_COMPATIBILITY=1' )
 
